﻿using System;
using System.Drawing;
using System.Windows.Forms;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.leftButton.Click  += leftButton_Click;
            this.rightButton.Click += rightButton_Click;

            SetLeftColor(Color.Yellow);
            SetRightColor(Color.Orange);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 왼쪽 버튼 클릭시 처리하기 - leftButton_Click(sender, e)

        /// <summary>
        /// 왼쪽 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void leftButton_Click(object sender, EventArgs e)
        {
            Color color;

            if(ShowColorDialog(out color))
            {
                SetLeftColor(color);
            }
        }

        #endregion
        #region 오른쪽 버튼 클릭시 처리하기 - rightButton_Click(sender, e)

        /// <summary>
        /// 오른쪽 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void rightButton_Click(object sender, EventArgs e)
        {
            Color color;

            if(ShowColorDialog(out color))
            {
                SetRightColor(color);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 색상 대화 상자 표시하기 - ShowColorDialog(color)

        /// <summary>
        /// 색상 대화 상자 표시하기
        /// </summary>
        /// <param name="color">색상</param>
        /// <returns>처리 결과</returns>
        public bool ShowColorDialog(out Color color)
        {
            color = new Color();

            ColorDialog colorDialog = new ColorDialog();

            if(colorDialog.ShowDialog() == DialogResult.OK)
            {
                color = colorDialog.Color;

                return true;
            }

            return false;
        }

        #endregion
        #region 왼쪽 색상 설정하기 - SetLeftColor(color)

        /// <summary>
        /// 왼쪽 색상 설정하기
        /// </summary>
        /// <param name="color">색상</param>
        private void SetLeftColor(Color color)
        {
            this.gradationPanel.LeftColor = color;

            this.leftButton.BackColor = color;

            this.gradationPanel.Refresh();
        }

        #endregion
        #region 오른쪽 색상 설정하기 - SetRightColor(color)

        /// <summary>
        /// 오른쪽 색상 설정하기
        /// </summary>
        /// <param name="color">색상</param>
        private void SetRightColor(Color color)
        {
            this.gradationPanel.RightColor = color;

            this.rightButton.BackColor = color;

            this.gradationPanel.Refresh();
        }

        #endregion
    }
}